Method: Google::Api::GoSettings#renamed_services

Defined in:
proto_docs/google/api/client.rb

#renamed_services::Google::Protobuf::Map{::String => ::String}

Returns Map of service names to renamed services. Keys are the package relative service names and values are the name to be used for the service client and call options.

publishing: go_settings: renamed_services: Publisher: TopicAdmin.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Map of service names to renamed services. Keys are the package relative service names and values are the name to be used for the service client and call options.

    publishing: go_settings: renamed_services: Publisher: TopicAdmin



325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'proto_docs/google/api/client.rb', line 325

class GoSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class RenamedServicesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end