Method: Google::Cloud::AppEngine::V1::Application#feature_settings

Defined in:
proto_docs/google/appengine/v1/application.rb

#feature_settings::Google::Cloud::AppEngine::V1::Application::FeatureSettings

Returns The feature specific settings to be used in the application.

Returns:



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'proto_docs/google/appengine/v1/application.rb', line 93

class Application
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Identity-Aware Proxy
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Whether the serving infrastructure will authenticate and
  #     authorize all incoming requests.
  #
  #     If true, the `oauth2_client_id` and `oauth2_client_secret`
  #     fields must be non-empty.
  # @!attribute [rw] oauth2_client_id
  #   @return [::String]
  #     OAuth2 client ID to use for the authentication flow.
  # @!attribute [rw] oauth2_client_secret
  #   @return [::String]
  #     OAuth2 client secret to use for the authentication flow.
  #
  #     For security reasons, this value cannot be retrieved via the API.
  #     Instead, the SHA-256 hash of the value is returned in the
  #     `oauth2_client_secret_sha256` field.
  # @!attribute [rw] oauth2_client_secret_sha256
  #   @return [::String]
  #     Hex-encoded SHA-256 hash of the client secret.
  class IdentityAwareProxy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The feature specific settings to be used in the application. These define
  # behaviors that are user configurable.
  # @!attribute [rw] split_health_checks
  #   @return [::Boolean]
  #     Boolean value indicating if split health checks should be used instead
  #     of the legacy health checks. At an app.yaml level, this means defaulting
  #     to 'readiness_check' and 'liveness_check' values instead of
  #     'health_check' ones. Once the legacy 'health_check' behavior is
  #     deprecated, and this value is always true, this setting can
  #     be removed.
  # @!attribute [rw] use_container_optimized_os
  #   @return [::Boolean]
  #     If true, use [Container-Optimized OS](https://cloud.google.com/container-optimized-os/)
  #     base image for VMs, rather than a base Debian image.
  class FeatureSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module ServingStatus
    # Serving status is unspecified.
    UNSPECIFIED = 0

    # Application is serving.
    SERVING = 1

    # Application has been disabled by the user.
    USER_DISABLED = 2

    # Application has been disabled by the system.
    SYSTEM_DISABLED = 3
  end

  module DatabaseType
    # Database type is unspecified.
    DATABASE_TYPE_UNSPECIFIED = 0

    # Cloud Datastore
    CLOUD_DATASTORE = 1

    # Cloud Firestore Native
    CLOUD_FIRESTORE = 2

    # Cloud Firestore in Datastore Mode
    CLOUD_DATASTORE_COMPATIBILITY = 3
  end
end