Class: Google::Cloud::AppEngine::V1::ErrorHandler
- Inherits:
-
Object
- Object
- Google::Cloud::AppEngine::V1::ErrorHandler
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/appengine/v1/app_yaml.rb
Overview
Custom static error page to be served when an error occurs.
Defined Under Namespace
Modules: ErrorCode
Instance Attribute Summary collapse
-
#error_code ⇒ ::Google::Cloud::AppEngine::V1::ErrorHandler::ErrorCode
Error condition this handler applies to.
-
#mime_type ⇒ ::String
MIME type of file.
-
#static_file ⇒ ::String
Static file content to be served for this error.
Instance Attribute Details
#error_code ⇒ ::Google::Cloud::AppEngine::V1::ErrorHandler::ErrorCode
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 58 class ErrorHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Error codes. module ErrorCode # Not specified. ERROR_CODE_DEFAULT is assumed. ERROR_CODE_UNSPECIFIED = 0 # All other error types. ERROR_CODE_DEFAULT = 0 # Application has exceeded a resource quota. ERROR_CODE_OVER_QUOTA = 1 # Client blocked by the application's Denial of Service protection # configuration. ERROR_CODE_DOS_API_DENIAL = 2 # Deadline reached before the application responds. ERROR_CODE_TIMEOUT = 3 end end |
#mime_type ⇒ ::String
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 58 class ErrorHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Error codes. module ErrorCode # Not specified. ERROR_CODE_DEFAULT is assumed. ERROR_CODE_UNSPECIFIED = 0 # All other error types. ERROR_CODE_DEFAULT = 0 # Application has exceeded a resource quota. ERROR_CODE_OVER_QUOTA = 1 # Client blocked by the application's Denial of Service protection # configuration. ERROR_CODE_DOS_API_DENIAL = 2 # Deadline reached before the application responds. ERROR_CODE_TIMEOUT = 3 end end |
#static_file ⇒ ::String
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 58 class ErrorHandler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Error codes. module ErrorCode # Not specified. ERROR_CODE_DEFAULT is assumed. ERROR_CODE_UNSPECIFIED = 0 # All other error types. ERROR_CODE_DEFAULT = 0 # Application has exceeded a resource quota. ERROR_CODE_OVER_QUOTA = 1 # Client blocked by the application's Denial of Service protection # configuration. ERROR_CODE_DOS_API_DENIAL = 2 # Deadline reached before the application responds. ERROR_CODE_TIMEOUT = 3 end end |