Class: Google::Cloud::AppEngine::V1::StaticFilesHandler

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/appengine/v1/app_yaml.rb

Overview

Files served directly to the user for a given URL, such as images, CSS stylesheets, or JavaScript source files. Static file handlers describe which files in the application directory are static files, and which URLs serve them.

Defined Under Namespace

Classes: HttpHeadersEntry

Instance Attribute Summary collapse

Instance Attribute Details

#application_readable::Boolean



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 183

class StaticFilesHandler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class HttpHeadersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#expiration::Google::Protobuf::Duration



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 183

class StaticFilesHandler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class HttpHeadersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#http_headers::Google::Protobuf::Map{::String => ::String}



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 183

class StaticFilesHandler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class HttpHeadersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#mime_type::String



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 183

class StaticFilesHandler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class HttpHeadersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#path::String



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 183

class StaticFilesHandler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class HttpHeadersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#require_matching_file::Boolean



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 183

class StaticFilesHandler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class HttpHeadersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#upload_path_regex::String



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 183

class StaticFilesHandler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class HttpHeadersEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end