Class: Google::Cloud::AppEngine::V1::UrlMap

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/appengine/v1/app_yaml.rb

Overview

URL pattern and description of how the URL should be handled. App Engine can handle URLs by executing application code or by serving static files uploaded with the version, such as images, CSS, or JavaScript.

Defined Under Namespace

Modules: RedirectHttpResponseCode

Instance Attribute Summary collapse

Instance Attribute Details

#api_endpoint::Google::Cloud::AppEngine::V1::ApiEndpointHandler

Returns Uses API Endpoints to handle requests.

Note: The following fields are mutually exclusive: api_endpoint, static_files, script. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AppEngine::V1::ApiEndpointHandler)

    Uses API Endpoints to handle requests.

    Note: The following fields are mutually exclusive: api_endpoint, static_files, script. If a field in that set is populated, all other fields in the set will automatically be cleared.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 123

class UrlMap
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Redirect codes.
  module RedirectHttpResponseCode
    # Not specified. `302` is assumed.
    REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED = 0

    # `301 Moved Permanently` code.
    REDIRECT_HTTP_RESPONSE_CODE_301 = 1

    # `302 Moved Temporarily` code.
    REDIRECT_HTTP_RESPONSE_CODE_302 = 2

    # `303 See Other` code.
    REDIRECT_HTTP_RESPONSE_CODE_303 = 3

    # `307 Temporary Redirect` code.
    REDIRECT_HTTP_RESPONSE_CODE_307 = 4
  end
end

#auth_fail_action::Google::Cloud::AppEngine::V1::AuthFailAction

Returns Action to take when users access resources that require authentication. Defaults to redirect.

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 123

class UrlMap
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Redirect codes.
  module RedirectHttpResponseCode
    # Not specified. `302` is assumed.
    REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED = 0

    # `301 Moved Permanently` code.
    REDIRECT_HTTP_RESPONSE_CODE_301 = 1

    # `302 Moved Temporarily` code.
    REDIRECT_HTTP_RESPONSE_CODE_302 = 2

    # `303 See Other` code.
    REDIRECT_HTTP_RESPONSE_CODE_303 = 3

    # `307 Temporary Redirect` code.
    REDIRECT_HTTP_RESPONSE_CODE_307 = 4
  end
end

#login::Google::Cloud::AppEngine::V1::LoginRequirement

Returns Level of login required to access this resource. Not supported for Node.js in the App Engine standard environment.

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 123

class UrlMap
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Redirect codes.
  module RedirectHttpResponseCode
    # Not specified. `302` is assumed.
    REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED = 0

    # `301 Moved Permanently` code.
    REDIRECT_HTTP_RESPONSE_CODE_301 = 1

    # `302 Moved Temporarily` code.
    REDIRECT_HTTP_RESPONSE_CODE_302 = 2

    # `303 See Other` code.
    REDIRECT_HTTP_RESPONSE_CODE_303 = 3

    # `307 Temporary Redirect` code.
    REDIRECT_HTTP_RESPONSE_CODE_307 = 4
  end
end

#redirect_http_response_code::Google::Cloud::AppEngine::V1::UrlMap::RedirectHttpResponseCode

Returns 30x code to use when performing redirects for the secure field. Defaults to 302.

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 123

class UrlMap
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Redirect codes.
  module RedirectHttpResponseCode
    # Not specified. `302` is assumed.
    REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED = 0

    # `301 Moved Permanently` code.
    REDIRECT_HTTP_RESPONSE_CODE_301 = 1

    # `302 Moved Temporarily` code.
    REDIRECT_HTTP_RESPONSE_CODE_302 = 2

    # `303 See Other` code.
    REDIRECT_HTTP_RESPONSE_CODE_303 = 3

    # `307 Temporary Redirect` code.
    REDIRECT_HTTP_RESPONSE_CODE_307 = 4
  end
end

#script::Google::Cloud::AppEngine::V1::ScriptHandler

Returns Executes a script to handle the requests that match this URL pattern. Only the auto value is supported for Node.js in the App Engine standard environment, for example "script": "auto".

Note: The following fields are mutually exclusive: script, static_files, api_endpoint. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AppEngine::V1::ScriptHandler)

    Executes a script to handle the requests that match this URL pattern. Only the auto value is supported for Node.js in the App Engine standard environment, for example "script": "auto".

    Note: The following fields are mutually exclusive: script, static_files, api_endpoint. If a field in that set is populated, all other fields in the set will automatically be cleared.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 123

class UrlMap
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Redirect codes.
  module RedirectHttpResponseCode
    # Not specified. `302` is assumed.
    REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED = 0

    # `301 Moved Permanently` code.
    REDIRECT_HTTP_RESPONSE_CODE_301 = 1

    # `302 Moved Temporarily` code.
    REDIRECT_HTTP_RESPONSE_CODE_302 = 2

    # `303 See Other` code.
    REDIRECT_HTTP_RESPONSE_CODE_303 = 3

    # `307 Temporary Redirect` code.
    REDIRECT_HTTP_RESPONSE_CODE_307 = 4
  end
end

#security_level::Google::Cloud::AppEngine::V1::SecurityLevel

Returns Security (HTTPS) enforcement for this URL.

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 123

class UrlMap
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Redirect codes.
  module RedirectHttpResponseCode
    # Not specified. `302` is assumed.
    REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED = 0

    # `301 Moved Permanently` code.
    REDIRECT_HTTP_RESPONSE_CODE_301 = 1

    # `302 Moved Temporarily` code.
    REDIRECT_HTTP_RESPONSE_CODE_302 = 2

    # `303 See Other` code.
    REDIRECT_HTTP_RESPONSE_CODE_303 = 3

    # `307 Temporary Redirect` code.
    REDIRECT_HTTP_RESPONSE_CODE_307 = 4
  end
end

#static_files::Google::Cloud::AppEngine::V1::StaticFilesHandler

Returns the contents of a file, such as an image, as the response.

Note: The following fields are mutually exclusive: static_files, script, api_endpoint. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AppEngine::V1::StaticFilesHandler)

    Returns the contents of a file, such as an image, as the response.

    Note: The following fields are mutually exclusive: static_files, script, api_endpoint. If a field in that set is populated, all other fields in the set will automatically be cleared.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 123

class UrlMap
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Redirect codes.
  module RedirectHttpResponseCode
    # Not specified. `302` is assumed.
    REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED = 0

    # `301 Moved Permanently` code.
    REDIRECT_HTTP_RESPONSE_CODE_301 = 1

    # `302 Moved Temporarily` code.
    REDIRECT_HTTP_RESPONSE_CODE_302 = 2

    # `303 See Other` code.
    REDIRECT_HTTP_RESPONSE_CODE_303 = 3

    # `307 Temporary Redirect` code.
    REDIRECT_HTTP_RESPONSE_CODE_307 = 4
  end
end

#url_regex::String

Returns URL prefix. Uses regular expression syntax, which means regexp special characters must be escaped, but should not contain groupings. All URLs that begin with this prefix are handled by this handler, using the portion of the URL after the prefix as part of the file path.

Returns:

  • (::String)

    URL prefix. Uses regular expression syntax, which means regexp special characters must be escaped, but should not contain groupings. All URLs that begin with this prefix are handled by this handler, using the portion of the URL after the prefix as part of the file path.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/appengine/v1/app_yaml.rb', line 123

class UrlMap
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Redirect codes.
  module RedirectHttpResponseCode
    # Not specified. `302` is assumed.
    REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED = 0

    # `301 Moved Permanently` code.
    REDIRECT_HTTP_RESPONSE_CODE_301 = 1

    # `302 Moved Temporarily` code.
    REDIRECT_HTTP_RESPONSE_CODE_302 = 2

    # `303 See Other` code.
    REDIRECT_HTTP_RESPONSE_CODE_303 = 3

    # `307 Temporary Redirect` code.
    REDIRECT_HTTP_RESPONSE_CODE_307 = 4
  end
end