Method: Google::Rpc::Status#details

Defined in:
proto_docs/google/rpc/status.rb

#details::Array<::Google::Protobuf::Any>

Returns A list of messages that carry the error details. There is a common set of message types for APIs to use.

Returns:

  • (::Array<::Google::Protobuf::Any>)

    A list of messages that carry the error details. There is a common set of message types for APIs to use.



43
44
45
46
# File 'proto_docs/google/rpc/status.rb', line 43

class Status
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end